package com.tfis.system.service.impl;

import java.util.List;
import com.tfis.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.tfis.system.mapper.FaultCaseViewCountMapper;
import com.tfis.system.domain.FaultCaseViewCount;
import com.tfis.system.service.IFaultCaseViewCountService;

/**
 * 故障案例查看次数管理Service业务层处理
 * 
 * @author allen
 * @date 2023-11-23
 */
@Service
public class FaultCaseViewCountServiceImpl implements IFaultCaseViewCountService 
{
    @Autowired
    private FaultCaseViewCountMapper faultCaseViewCountMapper;

    /**
     * 查询故障案例查看次数管理
     * 
     * @param id 故障案例查看次数管理主键
     * @return 故障案例查看次数管理
     */
    @Override
    public FaultCaseViewCount selectFaultCaseViewCountById(Long id)
    {
        return faultCaseViewCountMapper.selectFaultCaseViewCountById(id);
    }

    /**
     * 查询故障案例查看次数管理列表
     * 
     * @param faultCaseViewCount 故障案例查看次数管理
     * @return 故障案例查看次数管理
     */
    @Override
    public List<FaultCaseViewCount> selectFaultCaseViewCountList(FaultCaseViewCount faultCaseViewCount)
    {
        return faultCaseViewCountMapper.selectFaultCaseViewCountList(faultCaseViewCount);
    }

    /**
     * 新增故障案例查看次数管理
     * 
     * @param faultCaseViewCount 故障案例查看次数管理
     * @return 结果
     */
    @Override
    public int insertFaultCaseViewCount(FaultCaseViewCount faultCaseViewCount)
    {
        faultCaseViewCount.setCreateTime(DateUtils.getNowDate());
        return faultCaseViewCountMapper.insertFaultCaseViewCount(faultCaseViewCount);
    }

    /**
     * 修改故障案例查看次数管理
     * 
     * @param faultCaseViewCount 故障案例查看次数管理
     * @return 结果
     */
    @Override
    public int updateFaultCaseViewCount(FaultCaseViewCount faultCaseViewCount)
    {
        faultCaseViewCount.setUpdateTime(DateUtils.getNowDate());
        return faultCaseViewCountMapper.updateFaultCaseViewCount(faultCaseViewCount);
    }

    /**
     * 批量删除故障案例查看次数管理
     * 
     * @param ids 需要删除的故障案例查看次数管理主键
     * @return 结果
     */
    @Override
    public int deleteFaultCaseViewCountByIds(Long[] ids)
    {
        return faultCaseViewCountMapper.deleteFaultCaseViewCountByIds(ids);
    }

    /**
     * 删除故障案例查看次数管理信息
     * 
     * @param id 故障案例查看次数管理主键
     * @return 结果
     */
    @Override
    public int deleteFaultCaseViewCountById(Long id)
    {
        return faultCaseViewCountMapper.deleteFaultCaseViewCountById(id);
    }
}
